@@ -40,7 +40,7 @@ def setup_log(silent, verbose=False):
 
 
 def main():
-    """ Main program """
+    """Main program"""
     parse, options = parser(__version__)
 
     if options.flexibleq and not options.quality:
@@ -72,5 +72,5 @@ def main():
     except KeyboardInterrupt:
         print("")
     except (yaml.YAMLError, yaml.MarkedYAMLError) as e:
-        logging.error("Your settings file(s) contain invalid YAML syntax! Please fix and restart!, {}".format(str(e)))
+        logging.error("Your settings file(s) contain invalid YAML syntax! Please fix and restart!, %s", str(e))
         sys.exit(2)
