@@ -37,6 +37,8 @@ class Service:
             "showthumbnailurl": None,
             "episodethumbnailurl": None,
             "publishing_datetime": None,
+            "language": None,
+            "ext": None,
         }
 
         #  Config
@@ -53,7 +55,7 @@ class Service:
         else:
             self.http = http
 
-        logging.debug("service: {}".format(self.__class__.__name__.lower()))
+        logging.debug("service: %s", self.__class__.__name__.lower())
 
     @property
     def url(self):
@@ -142,7 +144,7 @@ class MetadataThumbMixin:
 
 
 class Generic(Service):
-    """ Videos embed in sites """
+    """Videos embed in sites"""
 
     def get(self, sites):
         data = self.http.request("get", self.url).text
@@ -177,7 +179,7 @@ class Generic(Service):
 
         match = re.search(r"tv4play.se/iframe/video/(\d+)?", data)
         if match:
-            url = "http://www.tv4play.se/?video_id=%s" % match.group(1)
+            url = f"http://www.tv4play.se/?video_id={match.group(1)}"
             for i in sites:
                 if i.handles(url):
                     return url, i(self.config, url)
@@ -189,16 +191,16 @@ class Generic(Service):
                 if i.handles(url):
                     return self.url, i(self.config, self.url)
 
-        match = re.search("(picsearch_ajax_auth|screen9-ajax-auth)", data)
+        match = re.search("cdn.screen9.com", data)
         if match:
-            url = "http://csp.picsearch.com"
+            url = "https://cdn.screen9.com"
             for i in sites:
                 if i.handles(url):
                     return self.url, i(self.config, self.url)
 
         match = re.search('iframe src="(//csp.screen9.com[^"]+)"', data)
         if match:
-            url = "http:%s" % match.group(1)
+            url = f"https:{match.group(1)}"
             for i in sites:
                 if i.handles(url):
                     return self.url, i(self.config, self.url)
