@@ -10,7 +10,7 @@ from svtplay_dl.utils.text import decode_html_entities
 
 
 class Aftonbladettv(Service):
-    supported_domains = ["svd.se"]
+    supported_domains = ["svd.se", "tv.aftonbladet.se"]
 
     def get(self):
         data = self.get_urldata()
@@ -19,16 +19,16 @@ class Aftonbladettv(Service):
         if not match:
             match = re.search('data-svpPlayer-video="([^"]+)"', data)
             if not match:
-                yield ServiceError("Can't find video info")
-                return
+                match = re.search("window.ASSET = ({.*})", data)
+                if not match:
+                    yield ServiceError("Can't find video info")
+                    return
         data = json.loads(decode_html_entities(match.group(1)))
-        streams = hlsparse(self.config, self.http.request("get", data["streamUrls"]["hls"]), data["streamUrls"]["hls"], output=self.output)
-        for n in list(streams.keys()):
-            yield streams[n]
+        yield from hlsparse(self.config, self.http.request("get", data["streamUrls"]["hls"]), data["streamUrls"]["hls"], output=self.output)
 
 
 class Aftonbladet(Service):
-    supported_domains = ["aftonbladet.se", "tv.aftonbladet.se"]
+    supported_domains = ["aftonbladet.se"]
 
     def get(self):
         data = self.get_urldata()
@@ -41,7 +41,7 @@ class Aftonbladet(Service):
         try:
             janson = json.loads(match.group(1))
         except json.decoder.JSONDecodeError:
-            yield ServiceError("Can't decode api request: {}".format(match.group(1)))
+            yield ServiceError(f"Can't decode api request: {match.group(1)}")
             return
 
         videos = self._get_video(janson)
