@@ -22,13 +22,13 @@ class Atg(Service):
         wanted_id = parse.path[7:]
         current_time = int((datetime.utcnow() - datetime.utcfromtimestamp(0)).total_seconds() * 1000)
 
-        api_url = "https://www.atgplay.se/api/{}/video/{}".format(current_time, wanted_id)
+        api_url = f"https://www.atgplay.se/api/{current_time}/video/{wanted_id}"
         video_assets = self.http.request("get", api_url)
 
         try:
             janson = json.loads(video_assets.text)
         except json.decoder.JSONDecodeError:
-            yield ServiceError("Can't decode api request: {}".format(video_assets.text))
+            yield ServiceError(f"Can't decode api request: {video_assets.text}")
             return
 
         if "title" in janson:
@@ -37,7 +37,4 @@ class Atg(Service):
         if "urls" in janson:
             for i in janson["urls"]:
                 if "m3u" == i:
-                    stream = hlsparse(self.config, self.http.request("get", janson["urls"]["m3u"]), janson["urls"]["m3u"], output=self.output)
-
-                    for key in list(stream.keys()):
-                        yield stream[key]
+                    yield from hlsparse(self.config, self.http.request("get", janson["urls"]["m3u"]), janson["urls"]["m3u"], output=self.output)
