@@ -5,7 +5,6 @@ import json
 import re
 
 from svtplay_dl.error import ServiceError
-from svtplay_dl.fetcher.hds import hdsparse
 from svtplay_dl.fetcher.hls import hlsparse
 from svtplay_dl.fetcher.http import HTTP
 from svtplay_dl.service import OpenGraphThumbMixin
@@ -43,8 +42,8 @@ class Bigbrother(Service, OpenGraphThumbMixin):
         videoplayer = match.group(1)
 
         dataurl = (
-            "http://c.brightcove.com/services/viewer/htmlFederated?flashID={}&playerID={}&playerKey={}"
-            "&isVid=true&isUI=true&dynamicStreaming=true&@videoPlayer={}".format(flashid, playerid, playerkey, videoplayer)
+            f"http://c.brightcove.com/services/viewer/htmlFederated?flashID={flashid}&"
+            f"playerID={playerid}&playerKey={playerkey}&isVid=true&isUI=true&dynamicStreaming=true&@videoPlayer={videoplayer}"
         )
         data = self.http.request("get", dataurl).content
         match = re.search(r"experienceJSON = ({.*});", data)
@@ -59,20 +58,8 @@ class Bigbrother(Service, OpenGraphThumbMixin):
             return
 
         for i in renditions:
-            if i["defaultURL"].endswith("f4m"):
-                streams = hdsparse(
-                    copy.copy(self.config),
-                    self.http.request("get", i["defaultURL"], params={"hdcore": "3.7.0"}),
-                    i["defaultURL"],
-                    output=self.output,
-                )
-                for n in list(streams.keys()):
-                    yield streams[n]
-
             if i["defaultURL"].endswith("m3u8"):
-                streams = hlsparse(self.config, self.http.request("get", i["defaultURL"]), i["defaultURL"], output=self.output)
-                for n in list(streams.keys()):
-                    yield streams[n]
+                yield from hlsparse(self.config, self.http.request("get", i["defaultURL"]), i["defaultURL"], output=self.output)
 
             if i["defaultURL"].endswith("mp4"):
                 yield HTTP(copy.copy(self.config), i["defaultURL"], i["encodingRate"] / 1024, output=self.output)
