@@ -1,9 +1,9 @@
 import logging
 import re
-from urllib.parse import urljoin
 from urllib.parse import urlparse
 
 from svtplay_dl.error import ServiceError
+from svtplay_dl.fetcher.dash import dashparse
 from svtplay_dl.fetcher.hls import hlsparse
 from svtplay_dl.service import Service
 
@@ -29,10 +29,7 @@ class Cmore(Service):
         tld = self._gettld()
         self.output["id"] = vid
 
-        metaurl = "https://playback-api.b17g.net/asset/{}?service=cmore.{}" "&device=browser&drm=widevine&protocol=dash%2Chls".format(
-            self.output["id"],
-            tld,
-        )
+        metaurl = f"https://playback-api.b17g.net/asset/{self.output['id']}?service=cmore.{tld}&device=browser&drm=widevine&protocol=dash%2Chls"
         res = self.http.get(metaurl)
         janson = res.json()
         self._autoname(janson)
@@ -40,35 +37,67 @@ class Cmore(Service):
             yield ServiceError("Can't play this because the video got drm.")
             return
 
-        url = "https://playback-api.b17g.net/media/{}?service=cmore.{}&device=browser&protocol=hls%2Cdash&drm=widevine".format(self.output["id"], tld)
-        res = self.http.request("get", url, cookies=self.cookies, headers={"authorization": "Bearer {}".format(token)})
+        url = f"https://playback-api.b17g.net/media/{self.output['id']}?service=cmore.{tld}&device=browser&protocol=hls%2Cdash&drm=widevine"
+        res = self.http.request("get", url, cookies=self.cookies, headers={"authorization": f"Bearer {token}"})
         if res.status_code > 200:
             yield ServiceError("Can't play this because the video is geoblocked.")
             return
 
-        if res.json()["playbackItem"]["type"] == "hls":
-            streams = hlsparse(
+        jansson = res.json()
+        if jansson["playbackItem"]["type"] == "hls":
+            yield from hlsparse(
                 self.config,
-                self.http.request("get", res.json()["playbackItem"]["manifestUrl"]),
-                res.json()["playbackItem"]["manifestUrl"],
+                self.http.request("get", jansson["playbackItem"]["manifestUrl"]),
+                jansson["playbackItem"]["manifestUrl"],
                 output=self.output,
+                httpobject=self.http,
+            )
+            yield from dashparse(
+                self.config,
+                self.http.request("get", jansson["playbackItem"]["manifestUrl"].replace(".m3u8", ".mpd")),
+                jansson["playbackItem"]["manifestUrl"].replace(".m3u8", ".mpd"),
+                output=self.output,
+                httpobject=self.http,
             )
-            for n in list(streams.keys()):
-                yield streams[n]
 
     def find_all_episodes(self, config):
         episodes = []
+        seasons = []
 
         token, message = self._login()
         if not token:
             logging.error(message)
-            return
-        res = self.http.get(self.url)
-        tags = re.findall('<a class="card__link" href="([^"]+)"', res.text)
-        for i in tags:
-            url = urljoin("https://www.cmore.{}/".format(self._gettld()), i)
-            if url not in episodes:
-                episodes.append(url)
+            return episodes
+
+        parse = urlparse(self.url)
+        url = f"https://www.cmore.{self._gettld()}/page-data{parse.path}/page-data.json"
+        res = self.http.get(url)
+        if res.status_code > 400:
+            logging.warning("Bad url? it only work with series")
+            return episodes
+
+        janson = res.json()
+
+        if "mutualSeasonData" in janson["result"]["pageContext"]:
+            path = janson["result"]["pageContext"]["mutualSeasonData"]["serieRelativeUrl"]
+            seasons = janson["result"]["pageContext"]["mutualSeasonData"]["seasonNumbers"]
+        elif "mutualEpisodeData" in janson["result"]["pageContext"]:
+            path = janson["result"]["pageContext"]["mutualEpisodeData"]["serieRelativeUrl"]
+            seasons = janson["result"]["pageContext"]["mutualEpisodeData"]["seasonNumbers"]
+        elif "serie" in janson["result"]["pageContext"]:
+            path = janson["result"]["pageContext"]["serie"]["relativeUrl"]
+            seasons = janson["result"]["pageContext"]["serie"]["seasonNumbers"]
+        else:
+            logging.warning("Can't find info needed to find episodes")
+
+        for season in seasons:
+            url = f"https://www.cmore.se/page-data{path}/sasong-{season}/page-data.json"
+            res = self.http.get(url)
+            janson = res.json()
+            for episode in janson["result"]["pageContext"]["season"]["selectedEpisodes"]:
+                episode_url = f'https://www.cmore.{self._gettld()}{episode["relativeUrl"]}'
+                if episode_url not in episodes:
+                    episodes.append(episode_url)
 
         if config.get("all_last") > 0:
             return sorted(episodes[-config.get("all_last") :])
@@ -84,10 +113,9 @@ class Cmore(Service):
     def _login(self):
         tld = self._gettld()
         if self.config.get("cmoreoperator"):
-            url = "https://tve.cmore.se/country/{}/operator/{}/user/{}/exists?client=cmore-web-prod".format(
-                tld,
-                self.config.get("cmoreoperator"),
-                self.config.get("username"),
+            url = (
+                f"https://tve.cmore.se/country/{tld}/operator/{self.config.get('cmoreoperator')}"
+                f"/user/{self.config.get('username')}/exists?client=cmore-web-prod"
             )
             post = {
                 "password": self.config.get("password"),
@@ -110,9 +138,9 @@ class Cmore(Service):
         return token, None
 
     def operatorlist(self):
-        res = self.http.get("https://tve.cmore.se/country/{}/operator?client=cmore-web-prod".format(self._gettld()))
+        res = self.http.get(f"https://tve.cmore.se/country/{self._gettld()}/operator?client=cmore-web-prod")
         for i in res.json()["data"]["operators"]:
-            print("operator: '{}'".format(i["name"].lower()))
+            print(f"operator: '{i['name'].lower()}")
 
     def _get_vid(self):
         res = self.http.get(self.url)
@@ -131,7 +159,6 @@ class Cmore(Service):
         if "seriesTitle" in janson["metadata"]:
             self.output["title"] = janson["metadata"]["seriesTitle"]
             self.output["episodename"] = janson["metadata"]["episodeTitle"]
-
         else:
             self.output["title"] = janson["metadata"]["title"]
         self.output["season"] = janson["metadata"]["seasonNumber"]
