@@ -17,7 +17,7 @@ class Disney(Service, OpenGraphThumbMixin):
 
     def get(self):
         parse = urlparse(self.url)
-        if parse.hostname == "video.disney.se" or parse.hostname == "disneyjunior.disney.se":
+        if parse.hostname in ("video.disney.se", "disneyjunior.disney.se"):
             data = self.get_urldata()
             match = re.search(r"Grill.burger=({.*}):", data)
             if not match:
@@ -65,8 +65,8 @@ class Disney(Service, OpenGraphThumbMixin):
             self.output["title"] = title
 
             url = (
-                "http://cdnapi.kaltura.com/html5/html5lib/v1.9.7.6/mwEmbedFrame.php?&wid={}&uiconf_id={}&entry_id={}"
-                "&playerId={}&forceMobileHTML5=true&urid=1.9.7.6&callback=mwi".format(partnerid, uiconfid, entryid, uniq)
+                f"http://cdnapi.kaltura.com/html5/html5lib/v1.9.7.6/mwEmbedFrame.php?&wid={partnerid}&"
+                f"uiconf_id={uiconfid}&entry_id={entryid}&playerId={uniq}&forceMobileHTML5=true&urid=1.9.7.6&callback=mwi"
             )
             data = self.http.request("get", url).text
             match = re.search(r"mwi\(({.*})\);", data)
@@ -79,10 +79,9 @@ class Disney(Service, OpenGraphThumbMixin):
             self.output["title"] = name
 
             url = (
-                "http://cdnapi.kaltura.com/p/{}/sp/{}00/playManifest/entryId/{}/format/applehttp/protocol/http/a.m3u8"
-                "?ks={}&referrer=aHR0cDovL3d3dy5kaXNuZXkuc2U=&".format(partnerid[1:], partnerid[1:], entryid, ks)
+                f"http://cdnapi.kaltura.com/p/{partnerid[1:]}/sp/{partnerid[1:]}00/playManifest/entryId/{entryid}"
+                f"/format/applehttp/protocol/http/a.m3u8?ks={ks}&referrer=aHR0cDovL3d3dy5kaXNuZXkuc2U=&"
             )
+
             redirect = self.http.check_redirect(url)
-            streams = hlsparse(self.config, self.http.request("get", redirect), redirect, output=self.output)
-            for n in list(streams.keys()):
-                yield streams[n]
+            yield from hlsparse(self.config, self.http.request("get", redirect), redirect, output=self.output)
