@@ -8,7 +8,7 @@ from svtplay_dl.error import ServiceError
 from svtplay_dl.fetcher.hls import hlsparse
 from svtplay_dl.service import OpenGraphThumbMixin
 from svtplay_dl.service import Service
-from svtplay_dl.subtitle import subtitle
+from svtplay_dl.subtitle import subtitle_probe
 
 
 class Flowonline(Service, OpenGraphThumbMixin):
@@ -21,19 +21,17 @@ class Flowonline(Service, OpenGraphThumbMixin):
             return
         parse = urlparse(self.url)
 
-        url = "{}://{}{}".format(parse.scheme, parse.netloc, match.group(1))
+        url = f"{parse.scheme}://{parse.netloc}{match.group(1)}"
 
         data = self.http.get(url)
 
         match = re.search('src="([^"]+vtt)"', data.text)
         if match:
-            yield subtitle(copy.copy(self.config), "wrst", match.group(1))
+            yield from subtitle_probe(copy.copy(self.config), match.group(1))
 
         match = re.search('source src="([^"]+)" type="application/x-mpegURL"', data.text)
         if not match:
             yield ServiceError("Cant find video file")
             return
 
-        streams = hlsparse(self.config, self.http.request("get", match.group(1)), match.group(1), output=self.output)
-        for n in list(streams.keys()):
-            yield streams[n]
+        yield from hlsparse(self.config, self.http.request("get", match.group(1)), match.group(1), output=self.output)
