@@ -33,8 +33,8 @@ class Mtvnn(Service, OpenGraphThumbMixin):
 
             wanted_id = match_id.group(1)
             url_service = (
-                "http://feeds.mtvnservices.com/od/feed/intl-mrss-player-feed?mgid=mgid:arc:episode:nick.intl:{}"
-                "&arcEp=nickelodeon.se&imageEp=nickelodeon.se&stage=staging&accountOverride=intl.mtvi.com&ep=a9cc543c".format(wanted_id)
+                f"http://feeds.mtvnservices.com/od/feed/intl-mrss-player-feed?mgid=mgid:arc:episode:nick.intl:{wanted_id}"
+                "&arcEp=nickelodeon.se&imageEp=nickelodeon.se&stage=staging&accountOverride=intl.mtvi.com&ep=a9cc543c"
             )
             service_asset = self.http.request("get", url_service)
             match_guid = re.search('<guid isPermaLink="false">(.*)</guid>', service_asset.text)
@@ -44,8 +44,8 @@ class Mtvnn(Service, OpenGraphThumbMixin):
                 return
 
             hls_url = (
-                "https://mediautilssvcs-a.akamaihd.net/services/MediaGenerator/{}?arcStage=staging&accountOverride=intl.mtvi.com&"
-                "billingSection=intl&ep=a9cc543c&acceptMethods=hls".format(match_guid.group(1))
+                f"https://mediautilssvcs-a.akamaihd.net/services/MediaGenerator/{match_guid.group(1)}?arcStage=staging&accountOverride=intl.mtvi.com&"
+                "billingSection=intl&ep=a9cc543c&acceptMethods=hls"
             )
             hls_asset = self.http.request("get", hls_url)
             xml = ET.XML(hls_asset.text)
@@ -56,7 +56,6 @@ class Mtvnn(Service, OpenGraphThumbMixin):
                 and xml.find("./video").find("item").find("rendition") is not None
                 and xml.find("./video").find("item").find("rendition").find("src") is not None
             ):
-
                 hls_url = xml.find("./video").find("item").find("rendition").find("src").text
                 stream = hlsparse(self.config, self.http.request("get", hls_url), hls_url, output=self.output)
                 for key in list(stream.keys()):
@@ -81,34 +80,33 @@ class Mtvnn(Service, OpenGraphThumbMixin):
             match = re.search("mtvnn.com:([^&]+)", mrssxmlurl)
             if match:
                 urlpart = match.group(1).replace("-", "/").replace("playlist", "playlists")  # it use playlists dunno from where it gets it
-                hlsapi = "http://api.mtvnn.com/v2/{}/{}.json?video_format=m3u8&callback=&".format(countrycode, urlpart)
+                hlsapi = f"http://api.mtvnn.com/v2/{countrycode}/{urlpart}.json?video_format=m3u8&callback=&"
                 data = self.http.request("get", hlsapi).text
 
                 dataj = json.loads(data)
                 for i in dataj["local_playlist_videos"]:
-                    streams = hlsparse(self.config, self.http.request("get", i["url"]), i["url"], output=self.output)
-                    for n in list(streams.keys()):
-                        yield streams[n]
+                    yield from hlsparse(self.config, self.http.request("get", i["url"]), i["url"], output=self.output)
 
     def find_all_episodes(self, config):
+        episodes = []
         match = re.search(r"data-franchise='([^']+)'", self.get_urldata())
         if match is None:
             logging.error("Couldn't program id")
-            return
+            return episodes
         programid = match.group(1)
         match = re.findall(r"<li class='([a-z]+ )?playlist-item( [a-z]+)*?'( data-[-a-z]+='[^']+')* data-item-id='([^']+)'", self.get_urldata())
         if not match:
             logging.error("Couldn't retrieve episode list")
-            return
+            return episodes
         episodNr = []
         for i in match:
             episodNr.append(i[3])
-        episodes = []
+
         n = 0
         for i in sorted(episodNr):
             if n == config.get("all_last"):
                 break
-            episodes.append("http://www.nickelodeon.se/serier/{}-something/videos/{}-something".format(programid, i))
+            episodes.append(f"http://www.nickelodeon.se/serier/{programid}-something/videos/{i}-something")
             n += 1
         return episodes
 
@@ -127,7 +125,7 @@ class MtvMusic(Service, OpenGraphThumbMixin):
         try:
             janson = json.loads(match.group(1))
         except Exception:
-            yield ServiceError("Can't decode api request: {}".format(match.group(1)))
+            yield ServiceError(f"Can't decode api request: {match.group(1)}")
             return
 
         parse = urlparse(self.url)
@@ -135,10 +133,7 @@ class MtvMusic(Service, OpenGraphThumbMixin):
 
         for n in janson:
             if wanted_id == str(n["id"]):
-
-                mrssxmlurl = "http://media-utils.mtvnservices.com/services/MediaGenerator/" "mgid:arc:video:mtv.se:{}?acceptMethods=hls".format(
-                    n["video_token"],
-                )
+                mrssxmlurl = f"http://media-utils.mtvnservices.com/services/MediaGenerator/mgid:arc:video:mtv.se:{n['video_token']}?acceptMethods=hls"
                 hls_asset = self.http.request("get", mrssxmlurl)
                 xml = ET.XML(hls_asset.text)
 
@@ -148,10 +143,5 @@ class MtvMusic(Service, OpenGraphThumbMixin):
                     and xml.find("./video").find("item").find("rendition") is not None
                     and xml.find("./video").find("item").find("rendition").find("src") is not None
                 ):
-
                     hls_url = xml.find("./video").find("item").find("rendition").find("src").text
-                    stream = hlsparse(self.config, self.http.request("get", hls_url), hls_url, output=self.output)
-
-                    if stream:
-                        for key in list(stream.keys()):
-                            yield stream[key]
+                    yield from hlsparse(self.config, self.http.request("get", hls_url), hls_url, output=self.output)
