@@ -19,7 +19,7 @@ class Mtvservices(Service):
         if not match:
             yield ServiceError("Can't find video file")
             return
-        url = "http://media.mtvnservices.com/player/html5/mediagen/?uri=%s" % match.group(1)
+        url = f"http://media.mtvnservices.com/player/html5/mediagen/?uri={match.group(1)}"
         data = self.http.request("get", url)
         start = data.index("<?xml version=")
         data = data[start:]
@@ -29,5 +29,5 @@ class Mtvservices(Service):
 
         for i in sa:
             temp = i.find("src").text.index("gsp.comedystor")
-            url = "http://mtvnmobile.vo.llnwd.net/kip0/_pxn=0+_pxK=18639+_pxE=mp4/44620/mtvnorigin/{}".format(i.find("src").text[temp:])
+            url = f"http://mtvnmobile.vo.llnwd.net/kip0/_pxn=0+_pxK=18639+_pxE=mp4/44620/mtvnorigin/{i.find('src').text[temp:]}"
             yield HTTP(copy.copy(self.config), url, i.attrib["height"], output=self.output)
