@@ -24,15 +24,13 @@ class Ruv(Service):
             if match:
                 janson = json.loads(match.group(1))
                 self.config.get("live", checklive(janson["result"][1]))
-                streams = hlsparse(self.config, self.http.request("get", janson["result"][1]), janson["result"][1], output=self.output)
-                for n in list(streams.keys()):
-                    yield streams[n]
+                yield from hlsparse(self.config, self.http.request("get", janson["result"][1]), janson["result"][1], output=self.output)
             else:
                 yield ServiceError("Can't find json info")
         else:
             match = re.search(r'<source [^ ]*[ ]*src="([^"]+)" ', self.get_urldata())
             if not match:
-                yield ServiceError("Can't find video info for: %s" % self.url)
+                yield ServiceError(f"Can't find video info for: {self.url}")
                 return
             if match.group(1).endswith("mp4"):
                 yield HTTP(copy.copy(self.config), match.group(1), 800, output=self.output)
