@@ -7,10 +7,12 @@ import hashlib
 import json
 import logging
 import re
+from urllib.parse import parse_qs
 from urllib.parse import urlparse
 
 from svtplay_dl.error import ServiceError
 from svtplay_dl.fetcher.hls import hlsparse
+from svtplay_dl.fetcher.hls import M3U8
 from svtplay_dl.service import OpenGraphThumbMixin
 from svtplay_dl.service import Service
 from svtplay_dl.subtitle import subtitle
@@ -19,7 +21,7 @@ from svtplay_dl.subtitle import subtitle
 country = {".se": "sv", ".dk": "da", ".no": "no"}
 
 
-class Viaplay(Service, OpenGraphThumbMixin):
+class Viafree(Service, OpenGraphThumbMixin):
     supported_domains = [
         "tv3play.ee",
         "tv3play.lv",
@@ -42,13 +44,11 @@ class Viaplay(Service, OpenGraphThumbMixin):
             yield ServiceError("You need to login")
             return
 
-        data = self.get_urldata()
-        match = re.search('}}}},("staticPages".*}}); windo', data)
+        match = re.search('}}}},("staticPages".*}}); windo', self.get_urldata())
         if not match:
             yield ServiceError("Cant find necessary info")
             return
-
-        janson = json.loads("{}{}".format("{", match.group(1)))
+        janson = self._jansonpage(match.group(1))
         video = None
         for play in janson["page"]["blocks"]:
             if "componentName" in play and play["componentName"] == "player":
@@ -62,40 +62,58 @@ class Viaplay(Service, OpenGraphThumbMixin):
         self._autoname(video)
 
         if "subtitles" in video["_embedded"]["program"] and "subtitlesWebvtt" in video["_embedded"]["program"]["subtitles"]:
-            yield subtitle(copy.copy(self.config), "wrst", video["_embedded"]["program"]["subtitles"]["subtitlesWebvtt"], output=self.output)
+            if "m3u8" in video["_embedded"]["program"]["subtitles"]["subtitlesWebvtt"]:
+                m3u8s = M3U8(self.http.get(video["_embedded"]["program"]["subtitles"]["subtitlesWebvtt"]).text)
+                yield subtitle(
+                    copy.copy(self.config),
+                    "wrstsegment",
+                    video["_embedded"]["program"]["subtitles"]["subtitlesWebvtt"],
+                    output=copy.copy(self.output),
+                    m3u8=m3u8s,
+                )
 
         res = self.http.get(video["_embedded"]["program"]["_links"]["streamLink"]["href"])
         janson = res.json()
         stream = janson["embedded"]["prioritizedStreams"][0]["links"]["stream"]
 
-        if video["_embedded"]["program"]["_links"]["streamLink"]:
-            streams = hlsparse(
+        if video["_embedded"]["program"]["_links"]["streamLink"] and stream["href"]:
+            parse = urlparse(stream["href"])
+            query = parse_qs(parse.query)
+            query.pop("filter", None)
+            query = "&".join(f"{key}={val[0]}".format(key, val) for (key, val) in query.items())
+            hls_url = f"https://{parse.netloc}{parse.path}?{query}"
+            yield from hlsparse(
                 self.config,
-                self.http.request("get", stream["href"]),
-                stream["href"],
+                self.http.request("get", hls_url),
+                hls_url,
                 output=self.output,
-                authorization="MTG-AT {}".format(self.token),
+                authorization=f"MTG-AT {self.token}",
             )
-            for n in list(streams.keys()):
-                yield streams[n]
+
         if "subtitles" in janson["embedded"] and len(janson["embedded"]["subtitles"]) > 0:
             lang = re.search(r"(\.\w\w)$", urlparse(self.url).netloc).group(1)
-            if lang in country:
-                language = country[lang]
-            else:
-                language = None
+
+            language = country.get(lang, None)
+            self.config.set("subtitle_preferred", language)
 
             if not self.config.get("get_all_subtitles"):
                 if not language:
-                    yield subtitle(copy.copy(self.config), "wrst", janson["embedded"]["subtitles"][0]["link"]["href"], output=self.output)
+                    yield subtitle(copy.deepcopy(self.config), "wrst", janson["embedded"]["subtitles"][0]["link"]["href"], output=self.output)
                 else:
                     for i in janson["embedded"]["subtitles"]:
-                        if i["data"]["language"] == language:
-                            yield subtitle(copy.copy(self.config), "wrst", i["link"]["href"], output=self.output)
+                        if i["data"]["language"] == language and i["data"]["sdh"] is False:
+                            yield subtitle(copy.deepcopy(self.config), "wrst", i["link"]["href"], output=self.output)
 
             else:
+                substitles = {}
                 for i in janson["embedded"]["subtitles"]:
-                    yield subtitle(copy.copy(self.config), "wrst", i["link"]["href"], i["data"]["language"], output=copy.copy(self.output))
+                    substitles[(i["data"]["language"], i["data"]["sdh"])] = i["link"]["href"]
+
+                for i in substitles:
+                    lang, shd = i
+                    if shd:
+                        lang = f"{lang}-shd"
+                    yield subtitle(copy.deepcopy(self.config), "wrst", substitles[i], lang, output=copy.copy(self.output))
 
     def find_all_episodes(self, config):
         episodes = []
@@ -104,20 +122,20 @@ class Viaplay(Service, OpenGraphThumbMixin):
         match = re.search('}}}},("staticPages".*}}); windo', data)
         if not match:
             logging.error("Cant find necessary info")
-            return
+            return episodes
 
-        janson = json.loads("{}{}".format("{", match.group(1)))
+        janson = self._jansonpage(match.group(1))
         seasons = []
 
         if janson["page"]["pageType"] == "player":
-            res = self.http.get("{}://{}{}".format(parse.scheme, parse.netloc, janson["page"]["blocks"][0]["_links"]["back"]["publicPath"]))
+            res = self.http.get(f"{parse.scheme}://{parse.netloc}{janson['page']['blocks'][0]['_links']['back']['publicPath']}")
             data = res.text
             match = re.search('}}}},("staticPages".*}}); windo', data)
             if not match:
                 logging.error("Cant find necessary info")
-                return
+                return episodes
 
-            janson = json.loads("{}{}".format("{", match.group(1)))
+            janson = self._jansonpage(match.group(1))
 
         for i in janson["page"]["blocks"]:
             if i["slug"] == "series_header" and "seasons" in i["seriesHeader"]:
@@ -143,14 +161,14 @@ class Viaplay(Service, OpenGraphThumbMixin):
                         if i["episode"]["episodeNumber"]:
                             videos_tmp.append(
                                 [
-                                    int("{}{}".format(i["episode"]["seasonNumber"], i["episode"]["episodeNumber"])),
-                                    "{}://{}{}".format(parse.scheme, parse.netloc, i["publicPath"]),
+                                    int(f"{i['episode']['seasonNumber']}{i['episode']['episodeNumber']}"),
+                                    f"{parse.scheme}://{parse.netloc}{i['publicPath']}",
                                 ],
                             )
                         elif config.get("include_clips"):
-                            clips.append("{}://{}{}".format(parse.scheme, parse.netloc, i["publicPath"]))
+                            clips.append(f"{parse.scheme}://{parse.netloc}{i['publicPath']}")
                     else:
-                        episodes.append("{}://{}{}".format(parse.scheme, parse.netloc, i["publicPath"]))
+                        episodes.append(f"{parse.scheme}://{parse.netloc}{i['publicPath']}")
         if videos_tmp:
             for i in sorted(videos_tmp, key=lambda x: x[0]):
                 episodes.append(i[1])
@@ -198,3 +216,6 @@ class Viaplay(Service, OpenGraphThumbMixin):
             self.token = res.json()["data"]["accessToken"]
             return True
         return False
+
+    def _jansonpage(self, text):
+        return json.loads(f"{{{text.replace('undefined', 'null')}")
