@@ -26,22 +26,17 @@ class Vimeo(Service, OpenGraphThumbMixin):
             page_config = json.loads(match_clip_page_cfg.group(1))
             player_url = page_config["player"]["config_url"]
         else:
-            yield ServiceError("Can't find video file for: {}".format(self.url))
+            yield ServiceError(f"Can't find video file for: {self.url}")
             return
 
         player_data = self.http.request("get", player_url).text
 
         if player_data:
-
             jsondata = json.loads(player_data)
 
             if ("hls" in jsondata["request"]["files"]) and ("fastly_skyfire" in jsondata["request"]["files"]["hls"]["cdns"]):
                 hls_elem = jsondata["request"]["files"]["hls"]["cdns"]["fastly_skyfire"]
-                stream = hlsparse(self.config, self.http.request("get", hls_elem["url"]), hls_elem["url"], output=self.output)
-
-                if stream:
-                    for n in list(stream.keys()):
-                        yield stream[n]
+                yield from hlsparse(self.config, self.http.request("get", hls_elem["url"]), hls_elem["url"], output=self.output)
 
             avail_quality = jsondata["request"]["files"]["progressive"]
             for i in avail_quality:
