@@ -303,29 +303,36 @@ class formatnameTest(unittest.TestCase):
             config.set("filename", item[0])
             service = Service(config, "localhost")
             service.output.update(item[1])
-            assert _formatname(service.output, config, "mp4") == item[2]
+            service.output["ext"] = "mp4"
+            assert str(_formatname(service.output, config)) == item[2]
 
 
 class formatnameTest2(unittest.TestCase):
     def test_formatnameEmpty(self):
         config = setup_defaults()
         service = Service(config, "http://localhost")
-        assert formatname(service.output, config) == "-service.mp4"
+        service.output["ext"] = "mp4"
+        assert str(formatname(service.output, config).name) == "-service.mp4"
 
     def test_formatnameOutput(self):
         config = setup_defaults()
-        config.set("output", "/tmp")
-        service = Service(config, "http://localhost")
         if platform.system() == "Windows":
-            assert formatname(service.output, config) == "/tmp.mp4"
+            config.set("output", "c:\\Users")
+            service = Service(config, "http://localhost")
+            service.output["ext"] = "mp4"
+            assert str(formatname(service.output, config)) == "c:\\Users\\-service.mp4"
         else:
-            assert formatname(service.output, config) == "/tmp/-service.mp4"
+            config.set("output", "/tmp")
+            service = Service(config, "http://localhost")
+            service.output["ext"] = "mp4"
+            assert str(formatname(service.output, config)) == "/tmp/-service.mp4"
 
     def test_formatnameBasedir(self):
         config = setup_defaults()
         service = Service(config, "http://localhost")
         service.output["basedir"] = True
-        assert formatname(service.output, config) == "-service.mp4"
+        service.output["ext"] = "mp4"
+        assert str(formatname(service.output, config).name) == "-service.mp4"
 
     def test_formatnameTvshow(self):
         config = setup_defaults()
@@ -334,7 +341,8 @@ class formatnameTest2(unittest.TestCase):
         service.output["title"] = "kalle"
         service.output["season"] = 2
         service.output["episode"] = 2
-        assert formatname(service.output, config) == "kalle.s02e02-service.mp4"
+        service.output["ext"] = "mp4"
+        assert str(formatname(service.output, config).name) == "kalle.s02e02-service.mp4"
 
     def test_formatnameTvshowSubfolder(self):
         config = setup_defaults()
@@ -344,10 +352,11 @@ class formatnameTest2(unittest.TestCase):
         service.output["title"] = "kalle"
         service.output["season"] = 2
         service.output["episode"] = 2
+        service.output["ext"] = "mp4"
         if platform.system() == "Windows":
-            assert formatname(service.output, config) == r"kalle\kalle.s02e02-service.mp4"
+            assert str(formatname(service.output, config)) == "kalle\\kalle.s02e02-service.mp4"
         else:
-            assert formatname(service.output, config) == "kalle/kalle.s02e02-service.mp4"
+            assert str(formatname(service.output, config)) == "kalle/kalle.s02e02-service.mp4"
 
     def test_formatnameTvshowSubfolderMovie(self):
         config = setup_defaults()
@@ -357,22 +366,24 @@ class formatnameTest2(unittest.TestCase):
         service.output["title"] = "kalle"
         service.output["season"] = 2
         service.output["episode"] = 2
+        service.output["ext"] = "mp4"
         if platform.system() == "Windows":
-            assert formatname(service.output, config) == r"movies\kalle.s02e02-service.mp4"
+            assert str(formatname(service.output, config)) == "movies\\kalle.s02e02-service.mp4"
         else:
-            assert formatname(service.output, config) == "movies/kalle.s02e02-service.mp4"
+            assert str(formatname(service.output, config)) == "movies/kalle.s02e02-service.mp4"
 
     def test_formatnameTvshowPath(self):
         config = setup_defaults()
         if platform.system() == "Windows":
-            config.set("path", "c:")
+            config.set("path", "c:\\")
         else:
             config.set("path", "/tmp")
         service = Service(config, "http://localhost")
         service.output["title"] = "kalle"
         service.output["season"] = 2
         service.output["episode"] = 2
+        service.output["ext"] = "mp4"
         if platform.system() == "Windows":
-            assert formatname(service.output, config) == r"c:kalle.s02e02-service.mp4"
+            assert str(formatname(service.output, config)) == "c:\\kalle.s02e02-service.mp4"
         else:
-            assert formatname(service.output, config) == "/tmp/kalle.s02e02-service.mp4"
+            assert str(formatname(service.output, config)) == "/tmp/kalle.s02e02-service.mp4"
