@@ -16,9 +16,11 @@ from svtplay_dl.subtitle import subtitle
 from svtplay_dl.utils.nfo import write_nfo_episode
 from svtplay_dl.utils.nfo import write_nfo_tvshow
 from svtplay_dl.utils.output import filename
+from svtplay_dl.utils.output import find_dupes
 from svtplay_dl.utils.output import formatname
 from svtplay_dl.utils.stream import list_quality
 from svtplay_dl.utils.stream import select_quality
+from svtplay_dl.utils.stream import subtitle_decider
 from svtplay_dl.utils.text import exclude
 
 
@@ -39,10 +41,10 @@ def get_multiple_media(urls, config):
 
 def get_media(url, options, version="Unknown"):
     if "http" not in url[:4]:
-        url = "http://%s" % url
+        url = f"http://{url}"
 
     if options.get("verbose"):
-        logging.debug("version: {}".format(version))
+        logging.debug("version: %s", version)
 
     stream = service_handler(sites, options, url)
     if not stream:
@@ -103,8 +105,7 @@ def get_one_media(stream):
             sys.exit(2)
 
     videos = []
-    subs = []
-    subfixes = []
+    subtitles = []
     error = []
     streams = stream.get()
     try:
@@ -119,7 +120,7 @@ def get_one_media(stream):
                     else:
                         videos.append(i)
                 if isinstance(i, subtitle):
-                    subs.append(i)
+                    subtitles.append(i)
     except Exception:
         if stream.config.get("verbose"):
             raise
@@ -140,63 +141,32 @@ def get_one_media(stream):
         pub_date = None
     if after_date is not None and pub_date is not None and pub_date.date() < after_date.date():
         logging.info(
-            "Video {}S{}E{} skipped since published {} before {}. ".format(
-                stream.output["title"],
-                stream.output["season"],
-                stream.output["episode"],
-                pub_date.date(),
-                after_date.date(),
-            ),
+            "Video %sS%dE%d skipped since published %s.",
+            stream.output["title"],
+            stream.output["season"],
+            stream.output["episode"],
+            pub_date.date(),
         )
         return
 
-    if stream.config.get("require_subtitle") and not subs:
+    if stream.config.get("require_subtitle") and not subtitles:
         logging.info("No subtitles available")
         return
 
-    if stream.config.get("subtitle") and stream.config.get("get_url"):
-        if subs:
-            if stream.config.get("get_all_subtitles"):
-                for sub in subs:
-                    print(sub.url)
-            else:
-                print(subs[0].url)
+    if not stream.config.get("list_quality"):
+        subtitle_decider(stream, subtitles)
         if stream.config.get("force_subtitle"):
             return
 
-    def options_subs_dl(subfixes):
-        if subs:
-            if stream.config.get("get_all_subtitles"):
-                for sub in subs:
-                    sub.download()
-                    if stream.config.get("merge_subtitle"):
-                        if sub.subfix:
-                            subfixes += [sub.subfix]
-                        else:
-                            stream.config.set("get_all_subtitles", False)
-            else:
-                subs[0].download()
-        elif stream.config.get("merge_subtitle"):
-            stream.config.set("merge_subtitle", False)
-
-    if stream.config.get("subtitle") and not stream.config.get("get_url"):
-        options_subs_dl(subfixes)
-        if stream.config.get("force_subtitle"):
-            if not subs:
-                logging.info("No subtitles available")
-            return
-
-    if stream.config.get("merge_subtitle") and not stream.config.get("subtitle"):
-        options_subs_dl(subfixes)
     if not videos:
         errormsg = None
         for exc in error:
             if errormsg:
-                errormsg = "{}. {}".format(errormsg, str(exc))
+                errormsg = f"{errormsg}. {str(exc)}"
             else:
                 errormsg = str(exc)
         if errormsg:
-            logging.error("No videos found. {}".format(errormsg))
+            logging.error("No videos found. %s", errormsg)
         else:
             logging.error("No videos found.")
     else:
@@ -211,9 +181,22 @@ def get_one_media(stream):
                 return
         try:
             fstream = select_quality(stream.config, videos)
-            if fstream.config.get("get_url"):
-                print(fstream.url)
-                return
+        except UIException as e:
+            logging.error(e)
+            return
+
+        if fstream.config.get("get_url"):
+            print(fstream.url)
+            return
+
+        dupe, fileame = find_dupes(fstream.output, stream.config)
+        if dupe and not stream.config.get("force"):
+            logging.warning("File (%s) already exists. Use --force to overwrite", fileame.name)
+            return
+        if fstream.config.get("output_format") and fstream.config.get("output_format").lower() not in ["mkv", "mp4"]:
+            logging.error("Unknown output format. please choose mp4 or mkv")
+            sys.exit(2)
+        try:
             logging.info("Selected to download %s, bitrate: %s format: %s", fstream.name, fstream.bitrate, fstream.format)
             fstream.download()
         except UIException as e:
@@ -225,12 +208,17 @@ def get_one_media(stream):
         if fstream.config.get("thumbnail") and hasattr(stream, "get_thumbnail"):
             stream.get_thumbnail(stream.config)
 
-        post = postprocess(fstream, fstream.config, subfixes)
-        if fstream.audio and post.detect:
-            post.merge()
-        if fstream.audio and not post.detect and fstream.finished:
-            logging.warning("Cant find ffmpeg/avconv. audio and video is in seperate files. if you dont want this use -P hls or hds")
-        if fstream.name == "hls" or fstream.config.get("remux"):
-            post.remux()
         if fstream.config.get("silent_semi") and fstream.finished:
-            logging.log(25, "Download of %s was completed" % fstream.options.output)
+            logging.log(25, "Download of %s was completed", formatname(fstream.output, fstream.config))
+
+        if fstream.config.get("no_postprocess") is True or all(fstream.config.get(x) for x in ["no_remux", "no_merge"]) is True:
+            logging.info("All done. Not postprocessing files, leaving them completely untouched.")
+            return
+
+        post = postprocess(fstream, fstream.config, subtitles)
+        if fstream.audio and not post.detect and fstream.finished:
+            logging.warning("Can't find ffmpeg/avconv. audio and video is in seperate files. if you dont want this use -P hls or hds")
+        if post.detect and fstream.config.get("no_merge") is False:
+            post.merge()
+        else:
+            logging.info("All done. Not postprocessing files, leaving them completely untouched.")
