@@ -13,6 +13,8 @@ if platform.system() == "Windows":
 else:
     CONFIGFILE = os.path.expanduser("~/.svtplay-dl.yaml")
 
+FILENAME = "{title}.s{season}e{episode}.{episodename}-{id}-{service}.{ext}"
+
 
 class Options:
     """
@@ -45,6 +47,7 @@ class Options:
     def get(self, key):
         if key in self.default:
             return self.default[key]
+        return None
 
     def get_variable(self):
         return self.default
@@ -57,8 +60,9 @@ def gen_parser(version="unknown"):
     parser = argparse.ArgumentParser(prog="svtplay-dl")
     general = parser.add_argument_group()
 
-    general.add_argument("--version", action="version", version="%(prog)s {}".format(version))
+    general.add_argument("--version", action="version", version=f"%(prog)s {version}")
     general.add_argument("-o", "--output", metavar="output", default=None, help="outputs to the given filename or folder")
+    general.add_argument("--filename", metavar="filename", default=FILENAME, help=f"filename format {FILENAME}")
     general.add_argument(
         "--subfolder",
         action="store_true",
@@ -67,7 +71,7 @@ def gen_parser(version="unknown"):
     )
     general.add_argument("--config", dest="configfile", metavar="configfile", default=CONFIGFILE, help="Specify configuration file")
     general.add_argument("-f", "--force", action="store_true", dest="force", default=False, help="overwrite if file exists already")
-    general.add_argument("-r", "--resume", action="store_true", dest="resume", default=False, help="resume a download (RTMP obsolete)")
+    # general.add_argument("-r", "--resume", action="store_true", dest="resume", default=False, help="resume a download (RTMP obsolete)")
     general.add_argument("-l", "--live", action="store_true", dest="live", default=False, help="enable for live streams (RTMP based ones)")
     general.add_argument("-c", "--capture_time", default=-1, type=int, metavar="capture_time", help="define capture time in minutes of a live stream")
     general.add_argument("-s", "--silent", action="store_true", dest="silent", default=False, help="be less verbose")
@@ -80,6 +84,7 @@ def gen_parser(version="unknown"):
     )
     general.add_argument("-u", "--username", default=None, help="username")
     general.add_argument("-p", "--password", default=None, help="password")
+    general.add_argument("--token", default=None, help="token")
     general.add_argument(
         "-t",
         "--thumbnail",
@@ -124,7 +129,6 @@ def gen_parser(version="unknown"):
         metavar="cookie1=value;cookie2=value2",
         help="A cookies to add to each HTTP request.",
     )
-    general.add_argument("--remux", dest="remux", default=False, action="store_true", help="Remux from one container to mp4 using ffmpeg or avconv")
     general.add_argument(
         "--exclude",
         dest="exclude",
@@ -176,13 +180,13 @@ def gen_parser(version="unknown"):
         dest="flexibleq",
         help="allow given quality (as above) to differ by an amount",
     )
-    quality.add_argument("-P", "--preferred", default=None, metavar="preferred", help="preferred download method (dash, hls, hds, or http)")
+    quality.add_argument("-P", "--preferred", default=None, metavar="preferred", help="preferred download method (dash, hls, or http)")
     quality.add_argument("--list-quality", dest="list_quality", action="store_true", default=False, help="list the quality for a video")
     quality.add_argument(
         "--stream-priority",
         dest="stream_prio",
         default=None,
-        metavar="dash,hls,hds,http",
+        metavar="dash,hls,http",
         help="If two streams have the same quality, choose the one you prefer",
     )
     quality.add_argument(
@@ -192,6 +196,24 @@ def gen_parser(version="unknown"):
         metavar="h264,h264-51",
         help="Choose the format you prefer, --list-quality to show which one to choose from",
     )
+    quality.add_argument(
+        "--audio-language",
+        dest="audio_language",
+        default=None,
+        help="Choose the language of the audio (it can override the default one), --list-quality to show which one to choose from",
+    )
+    quality.add_argument(
+        "--video-role",
+        dest="video_role",
+        default="main",
+        help="Choose the role of the video (it can override the default one), --list-quality to show which one to choose from",
+    )
+    quality.add_argument(
+        "--resolution",
+        dest="resolution",
+        default=None,
+        help="Choose what video resolution to download e.g. 480,720,1080. comma seperated",
+    )
 
     subtitle = parser.add_argument_group("Subtitle")
     subtitle.add_argument(
@@ -200,7 +222,7 @@ def gen_parser(version="unknown"):
         action="store_true",
         dest="subtitle",
         default=False,
-        help="download subtitle from the site if available",
+        help="download subtitle from the site if available. both merged and separately stored if used with -M",
     )
     subtitle.add_argument(
         "-M",
@@ -208,7 +230,7 @@ def gen_parser(version="unknown"):
         action="store_true",
         dest="merge_subtitle",
         default=False,
-        help="merge subtitle with video/audio file with corresponding ISO639-3 language code." "this invokes --remux automatically.",
+        help="merge subtitle with video/audio file with corresponding ISO639-3 language code. also saved separately if used with -S",
     )
     subtitle.add_argument(
         "--force-subtitle",
@@ -250,11 +272,37 @@ def gen_parser(version="unknown"):
     alleps.add_argument("-A", "--all-episodes", action="store_true", dest="all_episodes", default=False, help="try to download all episodes")
     alleps.add_argument("--all-last", dest="all_last", default=-1, type=int, metavar="NN", help="get last NN episodes instead of all episodes")
     alleps.add_argument("--include-clips", dest="include_clips", default=False, action="store_true", help="include clips from websites when using -A")
+    alleps.add_argument("-R", "--reverse", action="store_true", dest="reverse_list", default=False, help="Reverse download order")
 
     cmorep = parser.add_argument_group("C More")
     cmorep.add_argument("--cmore-operatorlist", dest="cmoreoperatorlist", default=False, action="store_true", help="show operatorlist for cmore")
     cmorep.add_argument("--cmore-operator", dest="cmoreoperator", default=None, metavar="operator")
 
+    postprocessing = parser.add_argument_group("Post-processing")
+    postprocessing.add_argument("--no-remux", dest="no_remux", default=False, action="store_true", help="Do not automatically remux to mp4")
+    postprocessing.add_argument(
+        "--no-merge",
+        dest="no_merge",
+        default=False,
+        action="store_true",
+        help="Do not automatically merge video, audio and possibly also subtitle(s) together",
+    )
+    postprocessing.add_argument("--no-postprocess", dest="no_postprocess", default=False, action="store_true", help="Do not postprocess anything")
+    postprocessing.add_argument(
+        "--keep-original",
+        dest="keep_original",
+        default=False,
+        action="store_true",
+        help="Do postprocessing while also keeping original files",
+    )
+    postprocessing.add_argument(
+        "--output-format",
+        dest="output_format",
+        default="mp4",
+        choices=["mp4", "mkv"],
+        help="format you want resulting file in (mkv or mp4), mp4 is default",
+    )
+
     parser.add_argument("urls", nargs="*")
 
     return parser
@@ -271,7 +319,7 @@ def setup_defaults():
     options.set("output", None)
     options.set("subfolder", False)
     options.set("configfile", CONFIGFILE)
-    options.set("resume", False)
+    # options.set("resume", False)
     options.set("live", False)
     options.set("capture_time", -1)
     options.set("silent", False)
@@ -306,23 +354,34 @@ def setup_defaults():
     options.set("ssl_verify", True)
     options.set("http_headers", None)
     options.set("format_preferred", None)
+    options.set("audio_language", None)
+    options.set("video_role", "main")
+    options.set("resolution", None)
     options.set("stream_prio", None)
-    options.set("remux", False)
+    options.set("no_remux", False)
+    options.set("no_merge", False)
+    options.set("no_postprocess", False)
+    options.set("keep_original", False)
     options.set("silent_semi", False)
     options.set("proxy", None)
     options.set("include_clips", False)
     options.set("cmoreoperatorlist", False)
-    options.set("filename", "{title}.s{season}e{episode}.{episodename}-{id}-{service}.{ext}")
+    options.set("filename", FILENAME)
     options.set("only_audio", False)
     options.set("only_video", False)
+    options.set("output_format", "mp4")
+    options.set("get_all_subtitles", False)
+    options.set("token", None)
+    options.set("reverse_list", False)
     return _special_settings(options)
 
 
 def parsertoconfig(config, parser):
     config.set("output", parser.output)
+    config.set("filename", parser.filename)
     config.set("subfolder", parser.subfolder)
     config.set("configfile", parser.configfile)
-    config.set("resume", parser.resume)
+    # config.set("resume", parser.resume)
     config.set("live", parser.live)
     config.set("capture_time", parser.capture_time)
     config.set("silent", parser.silent)
@@ -352,8 +411,14 @@ def parsertoconfig(config, parser):
     config.set("http_headers", parser.http_headers)
     config.set("cookies", parser.cookies)
     config.set("format_preferred", parser.format_preferred)
+    config.set("video_role", parser.video_role)
+    config.set("resolution", parser.resolution)
+    config.set("audio_language", parser.audio_language)
     config.set("stream_prio", parser.stream_prio)
-    config.set("remux", parser.remux)
+    config.set("no_remux", parser.no_remux)
+    config.set("no_merge", parser.no_merge)
+    config.set("no_postprocess", parser.no_postprocess)
+    config.set("keep_original", parser.keep_original)
     config.set("get_all_subtitles", parser.get_all_subtitles)
     config.set("get_raw_subtitles", parser.get_raw_subtitles)
     config.set("convert_subtitle_colors", parser.convert_subtitle_colors)
@@ -363,6 +428,9 @@ def parsertoconfig(config, parser):
     config.set("proxy", parser.proxy)
     config.set("only_audio", parser.only_audio)
     config.set("only_video", parser.only_video)
+    config.set("output_format", parser.output_format)
+    config.set("token", parser.token)
+    config.set("reverse_list", parser.reverse_list)
     return _special_settings(config)
 
 
@@ -372,9 +440,6 @@ def _special_settings(config):
             config.set("merge_subtitle", True)
         else:
             config.set("subtitle", True)
-    if config.get("merge_subtitle"):
-        config.set("remux", True)
-        config.set("subtitle", True)
 
     if config.get("silent_semi"):
         config.set("silent", True)
@@ -414,11 +479,25 @@ def readconfig(config, configfile, service=None, preset=None):
                 data = fd.read()
                 configdata = safe_load(data)
         except PermissionError:
-            logging.error("Permission denied while reading config: {}".format(configfile))
+            logging.error("Permission denied while reading config: %s", configfile)
 
     if configdata is None:
         return config
 
+    # migrate old service name to new
+    old_name_in_config = False
+    if "service" in configdata and "dplay" in configdata["service"]:
+        old_name_in_config = True
+        logging.warning("'dplay' have been renamed to 'discoveryplus'")
+        configdata["service"]["discoveryplus"] = configdata["service"].pop("dplay")
+
+    if "service" in configdata and "viaplay" in configdata["service"]:
+        old_name_in_config = True
+        logging.warning("'viaplay' have been renamed to 'viafree'")
+        configdata["service"]["viafree"] = configdata["service"].pop("viaplay")
+    if old_name_in_config:
+        logging.warning("Old service names still work at the moment. To avoid the warnings you need to rename the service(s) to the new name(s)")
+
     if "default" in configdata:
         config = merge(config.get_variable(), configdata["default"])
 
@@ -428,4 +507,4 @@ def readconfig(config, configfile, service=None, preset=None):
     if preset and "presets" in configdata and preset in configdata["presets"]:
         config = merge(config.get_variable(), configdata["presets"][preset])
 
-    return config
+    return _special_settings(config)
